@@ -13,7 +13,7 @@ else
 fi
 
 print_revision() {
-	echo "$1 (nagios-plugins 1.4.9) $2"
+	echo "$1 v$2 (nagios-plugins 1.4.11)"
 	$ECHO "The nagios plugins come with ABSOLUTELY NO WARRANTY. You may redistribute\ncopies of the plugins under the terms of the GNU General Public License.\nFor more information about these matters, see the file named COPYING.\n" | sed -e 's/\n/ /g'
 }
 
